<?php
/**
 * fabstar functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package fabstar
 */

if ( ! defined( '_S_VERSION' ) ) {
	// Replace the version number of the theme on each release.
	define( '_S_VERSION', '1.0.0' );
}

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function fabstar_setup() {
	/*
		* Make theme available for translation.
		* Translations can be filed in the /languages/ directory.
		* If you're building a theme based on fabstar, use a find and replace
		* to change 'fabstar' to the name of your theme in all the template files.
		*/
	load_theme_textdomain( 'fabstar', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
		* Let WordPress manage the document title.
		* By adding theme support, we declare that this theme does not use a
		* hard-coded <title> tag in the document head, and expect WordPress to
		* provide it for us.
		*/
	add_theme_support( 'title-tag' );

	/*
		* Enable support for Post Thumbnails on posts and pages.
		*
		* @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		*/
	add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus(
		array(
			'menu-1' => esc_html__( 'Primary', 'fabstar' ),
		)
	);
	
	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );

	/**
	 * Add support for core custom logo.
	 *
	 * @link https://codex.wordpress.org/Theme_Logo
	 */
	$fabstar_logo = array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		);
	add_theme_support( 'custom-logo', $fabstar_logo );
	add_theme_support('title_tag');
	
	/* recommends */
	
	add_theme_support( "wp-block-styles" );
	
	$fabstar_html = array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
		'style',
		'script',
	);
	add_theme_support( 'html5', $fabstar_html );
	add_theme_support( "responsive-embeds" );
	$fabstar_args = array(
			'default-text-color' => 'fff',
			'width'              => 1000,
			'height'             => 250,
			'flex-width'         => true,
			'flex-height'        => true,
		);
	add_theme_support( "custom-header", $fabstar_args );
	add_theme_support( "custom-background", $fabstar_args );
	add_theme_support( "align-wide" );
	add_editor_style();
	
}
add_action( 'after_setup_theme', 'fabstar_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function fabstar_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'fabstar_content_width', 640 );
}
add_action( 'after_setup_theme', 'fabstar_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function fabstar_widgets_init() {
		register_sidebar( array(
			'name' => __( 'Sidebar', 'fabstar' ),
			'id' => 'fabstar-sidebar',
			'description' => __( 'The Sidebar Widget Area', 'fabstar' ),
			'before_widget' => '<div id="%1$s" class="row w_sidebar %2$s">',
			'after_widget' => '</div>',
			'before_title' => '<h2>',
			'after_title' => '</h2>'
		) );

		register_sidebar( array(
			'name' => __( 'Footer Widget Area', 'fabstar' ),
			'id' => 'fabstar-footer',
			'description' => __( 'Footer Widget Area', 'fabstar' ),
			'before_widget' => '<div id="%1$s" class="col-md-3 col-sm-6 footer-widget %2$s">',
			'after_widget' => '</div>',
			'before_title' => '<div class="col-md-12 widget-heading"><h1>',
			'after_title' => '</h1></div>',
		) );             
}
add_action( 'widgets_init', 'fabstar_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function fabstar_scripts() {
	wp_enqueue_style( 'fabstar-style', get_stylesheet_uri(), array(), _S_VERSION );
	wp_style_add_data( 'fabstar-style', 'rtl', 'replace' );

	wp_enqueue_script( 'fabstar-navigation', get_template_directory_uri() . '/js/navigation.js', array(), _S_VERSION, true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'fabstar_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require( get_template_directory() . '/customizer.php' );

/* menu file */
require( get_template_directory(). '/core/menu/nav-walker.php' );
require get_template_directory() . '/core/menu/custom-header.php';

/* theme style */
function fabstar_theme_style(){
		wp_enqueue_style('bootstrap',get_template_directory_uri() . '/css/bootstrap/css/bootstrap.css');
		wp_enqueue_style('font-awesome-470', get_template_directory_uri() . '/css/font-awesome-4.7.0/css/font-awesome.css');
		
		wp_enqueue_style('fabstar-responsive-css', get_template_directory_uri() . '/css/responsive.css');
		wp_enqueue_style('fabstar-custom-css', get_template_directory_uri() . '/css/custom-style.css');
		wp_enqueue_style( 'slicknav',  get_template_directory_uri() . '/css/slicknav.css' );

		wp_enqueue_style( 'slick-theme',  get_template_directory_uri() . '/css/slick-theme.css' );
		wp_enqueue_style( 'slick',  get_template_directory_uri() . '/css/slick.css' );
		
		wp_enqueue_script('jquery');
		wp_enqueue_script('bootstrap-js',get_template_directory_uri().'/css/bootstrap/js/bootstrap.js');
		
		wp_enqueue_script( 'jquery-slicknav', get_template_directory_uri() . '/js/jquery.slicknav.js', array( 'jquery' ), _S_VERSION, true );
		wp_enqueue_script( 'slick', get_template_directory_uri() . '/js/slick.js', array( 'jquery' ), _S_VERSION, true );
	
		wp_enqueue_script('fabstar-main-js',get_template_directory_uri().'/js/main.js', array(), true, true);
		$fabstar_theme_options = fabstar_get_options();

}
add_action( 'wp_enqueue_scripts', 'fabstar_theme_style' );
function fabstar_default_settings() {
	$fabstar_theme_options=array(
		// For General Setting
			'custom_css'=> '',
			'fabstar_time'=>'on',
			'height'=>55,
			'width'=>200,
			'autoplay'=>'on',
			'read_more'=>__('Read More','fabstar'),
			'sticky_header'=>'on',
			'box_layout'=>'1',
			
			// For Slider Setting
			'fabstar_slider'=> 'on',
			'slide_image_1'=> '',
			'slide_image_2'=> '',
			'slide_image_3'=> '',
			'slider_speed'=>3000,
			'fabstar_sliders'=>'1',
			
			// For Service Setting
			'fabstar_services'=> 'on',
			'fabstar_service_heading'=> 'Services',
			'fabstar_service_desc'=> '',
			'ser_img_1'=> '',
			'ser_img_2'=> '',
			'ser_img_3'=> '',
			
			// For Portfolio Setting
			'fabstar_portfolio'=>'on',
			'portfolio_category'=>'',
			'fabstar_portfolio_heading'=>'Portfolio',
			'fabstar_portfolio_desc'=>'',
			
			// For Blog Setting
			'fabstar_blog'=> 'on',
			'fabstar_blog_title'=> 'Blog',
			'fabstar_blog_desc'=> '',
			'blog_preview'=>2,
			'blog_category'=>'',
				
			//For Social Media Setting
			'fabstar_social_media'=>'on',
			'fabstar_footer_social_media'=>'on',
			'facbook_link'=>'#',
			'twitter_link'=>'#',
			'youtube_link'=>'#',
			'linkdin_link'=>'#',
			
			//search
			'search_form' => 'on',
			
			// For Footer Setting					
			'fabstar_footer_link'=>'',
			'fabstar_footer_link_text'=> '',
			'fabstar_footer_text'=> __('Copyright  &#169; All Right Reserved 2019 | fabstar developed By','fabstar'),
			);
	return apply_filters( 'fabstar_options', $fabstar_theme_options );	
}

	// Options API	
	function fabstar_get_options() 
	{	return wp_parse_args(get_theme_mod('fabstar_options') , fabstar_default_settings());   }
	// For Post thumbnail
	if ( function_exists( 'add_image_size' ) ) add_theme_support( 'post-thumbnails' );

		if ( function_exists( 'add_image_size' ) ) { 
			add_image_size ('fabstar-slider-thumb', 1920, 800,true);
			add_image_size ('fabstar-post-thumb', 400, 300,true);
			add_image_size ('fabstar-service-thumb', 200, 150,true);
			add_image_size ('fabstar-portfolio_thumb', 440, 280,true);
		}

	function fabstar_custom_excerpt_length( $length ) {
		$length = 20;
		if ( is_admin() ) return $length; 
		return $length;
	}
	add_filter( 'excerpt_length', 'fabstar_custom_excerpt_length', 999 );

	//For Excerpt content
	function fabstar_excerpt_more( $more ) {
		$more = '.';
		if ( is_admin() ) return $more;
		return $more;
	}
	add_filter('excerpt_more', 'fabstar_excerpt_more');
	
	function fabstar_keep_my_links($text) {
		global $post;
		if ( '' == $text ) {
			$text = get_the_content('');
			$text = apply_filters('the_content', $text);
			$text = str_replace('\]\]\>', ']]&gt;', $text);
			$text = preg_replace('@<script[^>]*?>.*?</script>@si', '', $text);
			$text = strip_tags($text, '<a>');
		  }
		  return $text;
	}
	remove_filter('get_the_excerpt', 'wp_trim_excerpt');
	add_filter('get_the_excerpt', 'fabstar_keep_my_links');
